@@ -27,10 +27,6 @@
  * See the ChangeLog files for a list of changes. 
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
 
@@ -44,9 +40,9 @@
 #include <gedit-utils.h>
 
 #define MENU_ITEM_LABEL		N_("_Word Count")
-#define MENU_ITEM_PATH		"/menu/Tools/ToolsOps_2/"
+#define MENU_ITEM_PATH		"/menu/Search/SearchOps_3/"
 #define MENU_ITEM_NAME		"PluginWordCount"	
-#define MENU_ITEM_TIP		N_("Get info on current document")
+#define MENU_ITEM_TIP		N_("Get info on current document.")
 
 typedef struct _DocInfoDialog DocInfoDialog;
 
@@ -118,13 +114,18 @@ get_dialog ()
 
 	if (dialog != NULL)
 	{
+		gdk_window_show (dialog->dialog->window);
+		gdk_window_raise (dialog->dialog->window);
+		gtk_widget_grab_focus (dialog->dialog);
+
 		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
 				window);
-
-		gtk_window_present (GTK_WINDOW (dialog->dialog));
-		
+	
 		gtk_widget_grab_focus (dialog->dialog);
 
+		if (!GTK_WIDGET_VISIBLE (dialog->dialog))
+			gtk_widget_show (dialog->dialog);
+
 		return dialog;
 	}
 
@@ -150,7 +151,7 @@ get_dialog ()
 
 	/* Add the update button */
 	gedit_dialog_add_button (GTK_DIALOG (dialog->dialog), 
-				 _("_Update"), GTK_STOCK_REFRESH, GTK_RESPONSE_OK);
+				 _("Update"), GTK_STOCK_REFRESH, GTK_RESPONSE_OK);
 
 	content			= glade_xml_get_widget (gui, "docinfo_dialog_content");
 
@@ -176,11 +177,11 @@ get_dialog ()
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GTK_RESPONSE_OK);
 
-	g_signal_connect (G_OBJECT (dialog->dialog), "destroy",
-			   G_CALLBACK (dialog_destroyed), &dialog);
+	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
+			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
 
-	g_signal_connect (G_OBJECT (dialog->dialog), "response",
-			   G_CALLBACK (dialog_response_handler), dialog);
+	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
+			   GTK_SIGNAL_FUNC (dialog_response_handler), dialog);
 
 	g_object_unref (gui);
 
@@ -232,7 +233,7 @@ word_count_real (void)
 		return;
 	}
 
-	text = gedit_document_get_chars (doc, 0, -1);
+	text = gedit_document_get_buffer (doc);
 	g_return_if_fail (g_utf8_validate (text, -1, NULL));
 
 	lines = gedit_document_get_line_count (doc);
@@ -359,6 +360,13 @@ init (GeditPlugin *pd)
 	/* initialize */
 	gedit_debug (DEBUG_PLUGINS, "");
      
+	pd->name = _("Word count");
+	pd->desc = _("The word count plugin analyzes the current document and determines the number "
+		     "of words, lines, characters and non-space characters in it "
+		     "and display the result.");
+	pd->author = "Paolo Maggi <maggi@athena.polito.it>";
+	pd->copyright = _("Copyright (C) 2002 - Paolo Maggi");
+	
 	pd->private_data = NULL;
 		
 	return PLUGIN_OK;
