@@ -30,8 +30,12 @@
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
 
-#include "gedit-plugin.h"
-#include "gedit-debug.h"
+#include <string.h>
+
+#include <gedit-plugin.h>
+#include <gedit-debug.h>
+#include <gedit-utils.h>
+#include <gedit-menus.h>
 
 #define MENU_ITEM_LABEL		N_("Insert shell _output")
 #define MENU_ITEM_PATH		"/menu/Edit/EditOps_4/"
@@ -58,6 +62,12 @@ static void	run_command_cb (BonoboUIComponent *uic, gpointer user_data,
 			       const gchar* verbname);
 static gboolean	run_command_real (ShellOutputDialog *dialog);
 
+G_MODULE_EXPORT GeditPluginState update_ui (GeditPlugin *plugin, BonoboWindow *window);
+G_MODULE_EXPORT GeditPluginState destroy (GeditPlugin *pd);
+G_MODULE_EXPORT GeditPluginState activate (GeditPlugin *pd);
+G_MODULE_EXPORT GeditPluginState deactivate (GeditPlugin *pd);
+G_MODULE_EXPORT GeditPluginState init (GeditPlugin *pd);
+
 gchar *current_directory = NULL;
 
 static void
@@ -101,7 +111,6 @@ get_dialog ()
 	GladeXML *gui;
 	GtkWindow *window;
 	GtkWidget *content;
-	GtkWidget *button;
 
 	gedit_debug (DEBUG_PLUGINS, "");
 
@@ -213,13 +222,12 @@ run_command_real (ShellOutputDialog *dialog)
 	const gchar    *directory_string = NULL ;
 	gboolean  retval;
 	gchar 	**argv = 0;
-	GError   *error = NULL;
 	gchar    *standard_output = NULL;
 	GeditDocument	*doc;
 	
 	gedit_debug (DEBUG_PLUGINS, "");
 
-	g_return_if_fail (dialog != NULL);
+	g_return_val_if_fail (dialog != NULL, FALSE);
 
 	doc = gedit_get_active_document ();
 
@@ -340,25 +348,27 @@ destroy (GeditPlugin *plugin)
 	plugin->deactivate (plugin);
 
 	g_free (current_directory);
+
+	return PLUGIN_OK;
 }
 	
 G_MODULE_EXPORT GeditPluginState
 update_ui (GeditPlugin *plugin, BonoboWindow *window)
 {
-	BonoboUIEngine *ui_engine;
+	BonoboUIComponent *uic;
 	GeditDocument *doc;
 	
 	gedit_debug (DEBUG_PLUGINS, "");	
 	g_return_val_if_fail (window != NULL, PLUGIN_ERROR);
 
-	ui_engine = bonobo_window_get_ui_engine (window);
+	uic = gedit_get_ui_component_from_window (window);
 
 	doc = gedit_get_active_document ();
 
 	if ((doc == NULL) || gedit_document_is_readonly (doc))		
-		gedit_menus_set_verb_sensitive (ui_engine, "/commands/" MENU_ITEM_NAME, FALSE);
+		gedit_menus_set_verb_sensitive (uic, "/commands/" MENU_ITEM_NAME, FALSE);
 	else
-		gedit_menus_set_verb_sensitive (ui_engine, "/commands/" MENU_ITEM_NAME, TRUE);
+		gedit_menus_set_verb_sensitive (uic, "/commands/" MENU_ITEM_NAME, TRUE);
 
 	return PLUGIN_OK;
 }
@@ -366,81 +376,35 @@ update_ui (GeditPlugin *plugin, BonoboWindow *window)
 G_MODULE_EXPORT GeditPluginState
 activate (GeditPlugin *pd)
 {
-	GList* top_windows;
-	
-	gedit_debug (DEBUG_PLUGINS, "");
+	GList *top_windows;
+        gedit_debug (DEBUG_PLUGINS, "");
 
-	top_windows = gedit_get_top_windows ();
-	g_return_val_if_fail (top_windows != NULL, PLUGIN_ERROR);
-       
-	while (top_windows)
-	{
-		BonoboUIComponent* ui_component;
-		gchar *item_path;
-		ui_component = gedit_get_ui_component_from_window (
-					BONOBO_WINDOW (top_windows->data));
-		
-		item_path = g_strdup (MENU_ITEM_PATH MENU_ITEM_NAME);
+        top_windows = gedit_get_top_windows ();
+        g_return_val_if_fail (top_windows != NULL, PLUGIN_ERROR);
 
-		if (!bonobo_ui_component_path_exists (ui_component, item_path, NULL))
-		{
-			gchar *xml;
-					
-			xml = g_strdup_printf ("<menuitem name=\"%s\" verb=\"\""
-					" _label=\"%s\" _tip=\"%s\" hidden=\"0\" />", 
-					MENU_ITEM_NAME, MENU_ITEM_LABEL, MENU_ITEM_TIP);
+        while (top_windows)
+        {
+		gedit_menus_add_menu_item (BONOBO_WINDOW (top_windows->data),
+				     MENU_ITEM_PATH, MENU_ITEM_NAME,
+				     MENU_ITEM_LABEL, MENU_ITEM_TIP,
+				     GTK_STOCK_EXECUTE, run_command_cb);
 
-			bonobo_ui_component_set_translate (ui_component, 
-					MENU_ITEM_PATH, xml, NULL);
+                pd->update_ui (pd, BONOBO_WINDOW (top_windows->data));
 
-			bonobo_ui_component_set_translate (ui_component, 
-					"/commands/", "<cmd name = \"" MENU_ITEM_NAME "\" "
-					"pixtype=\"stock\" pixname=\"gtk-execute\"/>", NULL);
+                top_windows = g_list_next (top_windows);
+        }
 
-			bonobo_ui_component_add_verb (ui_component, 
-					MENU_ITEM_NAME, run_command_cb, 
-					      NULL); 
-
-			g_free (xml);
-		}
-		
-		g_free (item_path);
-
-		pd->update_ui (pd, BONOBO_WINDOW (top_windows->data));
-
-		top_windows = g_list_next (top_windows);
-	}
+        return PLUGIN_OK;
 }
 
 G_MODULE_EXPORT GeditPluginState
 deactivate (GeditPlugin *pd)
 {
-	GList* top_windows;
-	
 	gedit_debug (DEBUG_PLUGINS, "");
+	
+	gedit_menus_remove_menu_item_all (MENU_ITEM_PATH, MENU_ITEM_NAME);
 
-	top_windows = gedit_get_top_windows ();
-	g_return_val_if_fail (top_windows != NULL, PLUGIN_ERROR);
-       
-	while (top_windows)
-	{
-		BonoboUIComponent* ui_component;
-		gchar *item_path;
-		ui_component = gedit_get_ui_component_from_window (
-					BONOBO_WINDOW (top_windows->data));
-		
-		item_path = g_strdup (MENU_ITEM_PATH MENU_ITEM_NAME);
-
-		if (bonobo_ui_component_path_exists (ui_component, item_path, NULL))
-		{
-			bonobo_ui_component_rm (ui_component, item_path, NULL);
-			bonobo_ui_component_rm (ui_component, "/commands/" MENU_ITEM_NAME, NULL);
-		}
-		
-		g_free (item_path);
-		
-		top_windows = g_list_next (top_windows);
-	}
+	return PLUGIN_OK;
 }
 
 G_MODULE_EXPORT GeditPluginState
