@@ -120,6 +120,8 @@ struct _GeditPreferencesDialogPrivate
 
 	/* Save page */
 	GtkWidget	*backup_copy_checkbutton;
+	GtkWidget	*auto_save_checkbutton;
+	GtkWidget	*auto_save_spinbutton;
 	GtkWidget	*utf8_radiobutton;
 	GtkWidget	*locale_if_possible_radiobutton;
 	GtkWidget	*locale_if_previous_radiobutton;
@@ -199,7 +201,7 @@ static CategoriesTreeItem user_interface [] =
 	{_("MDI"), NULL, MDI_SETTINGS},
 #endif
 
-	NULL
+	{ NULL }
 };
 
 static CategoriesTreeItem editor_behavior [] =
@@ -214,14 +216,14 @@ static CategoriesTreeItem editor_behavior [] =
 	{_("Wrap mode"), NULL, WRAP_MODE_SETTINGS},
 	{_("Line numbers"), NULL , LINE_NUMBERS_SETTINGS},
 
-	NULL
+	{ NULL }
 };
 
 static CategoriesTreeItem print [] =
 {
 	{_("Page"), NULL, PRINT_SETTINGS},
 
-	NULL
+	{ NULL }
 };
 
 static CategoriesTreeItem toplevel [] =
@@ -229,7 +231,7 @@ static CategoriesTreeItem toplevel [] =
 	{_("Editor"), editor_behavior, LOGO},
 	{_("Print"), print, LOGO},
 	{_("User interface"), user_interface, LOGO},
-	NULL
+	{ NULL }
 };
 
 GtkType
@@ -592,7 +594,7 @@ gedit_preferences_dialog_setup_toolbar_page (GeditPreferencesDialog *dlg, GladeX
 				GTK_TOGGLE_BUTTON (dlg->priv->toolbar_icon_text_radiobutton), TRUE);
 			break;
 
-		dafult:
+		default:
 			g_return_val_if_fail (FALSE, FALSE);
 	}
 	
@@ -731,8 +733,7 @@ gedit_preferences_dialog_default_font_colors_checkbutton_toggled (GtkToggleButto
 static gboolean 
 gedit_preferences_dialog_setup_font_and_colors_page (GeditPreferencesDialog *dlg, GladeXML *gui)
 {
-	GeditView* active_view = NULL;
-	GtkWidget* font_label;
+	GtkWidget *font_label;
 	
 	gedit_debug (DEBUG_PREFS, "");
 	
@@ -849,6 +850,8 @@ gedit_preferences_dialog_setup_undo_page (GeditPreferencesDialog *dlg, GladeXML
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->undo_checkbutton), 
 			gedit_settings->undo_levels > 0);
+
+	return TRUE;
 }
 
 
@@ -863,6 +866,8 @@ gedit_preferences_dialog_setup_tabs_page (GeditPreferencesDialog *dlg, GladeXML
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (dlg->priv->tabs_width_spinbutton),
 					   (guint) gedit_settings->tab_size);
+
+	return TRUE;
 }
 
 static gboolean 
@@ -885,6 +890,8 @@ gedit_preferences_dialog_setup_logo_page (GeditPreferencesDialog *dlg, GladeXML
 	g_object_set_property (G_OBJECT (logo), "file" , &value);
 
 	g_value_unset (&value);
+
+	return TRUE;
 }
 
 static gboolean 
@@ -925,6 +932,12 @@ gedit_preferences_dialog_setup_save_page (GeditPreferencesDialog *dlg, GladeXML
 	
 	dlg->priv->backup_copy_checkbutton = glade_xml_get_widget (gui, 
 			"backup_copy_checkbutton");
+	
+	dlg->priv->auto_save_checkbutton = glade_xml_get_widget (gui, 
+			"auto_save_checkbutton");
+
+	dlg->priv->auto_save_spinbutton = glade_xml_get_widget (gui, 
+			"auto_save_spinbutton");
 
 	dlg->priv->utf8_radiobutton= glade_xml_get_widget (gui, 
 			"utf8_radiobutton"); 
@@ -945,6 +958,12 @@ gedit_preferences_dialog_setup_save_page (GeditPreferencesDialog *dlg, GladeXML
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->backup_copy_checkbutton),
 				      gedit_settings->create_backup_copy);
 
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->auto_save_checkbutton),
+				      gedit_settings->auto_save);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (dlg->priv->auto_save_spinbutton),
+				    gedit_settings->auto_save_interval);
+
+
 	switch (gedit_settings->save_encoding)
 	{
 		case GEDIT_SAVE_ALWAYS_UTF8:
@@ -1042,7 +1061,6 @@ gboolean
 gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 {
 	GeditPreferences old_prefs;
-	gint index;
 	const gchar* font;
 	guint16 dummy;
 
@@ -1173,6 +1191,13 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 	gedit_settings->create_backup_copy = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->backup_copy_checkbutton));
 
+	gedit_settings->auto_save = 
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->auto_save_checkbutton));
+	gedit_settings->auto_save_interval =
+		gtk_spin_button_get_value (GTK_SPIN_BUTTON (dlg->priv->auto_save_spinbutton));
+
+	
+
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dlg->priv->utf8_radiobutton)))
 		gedit_settings->save_encoding = GEDIT_SAVE_ALWAYS_UTF8;
 	else
