@@ -372,9 +372,6 @@ gedit_document_new_with_uri (const gchar *uri, GError **error)
 void 		
 gedit_document_set_readonly (GeditDocument *document, gboolean readonly)
 {
-	GtkTextIter start;
-	GtkTextIter end;
-
 	gedit_debug (DEBUG_DOCUMENT, "");
 
 	g_return_if_fail (document != NULL);
@@ -406,20 +403,6 @@ gedit_document_set_readonly (GeditDocument *document, gboolean readonly)
 	if (document->priv->readonly == readonly) 
 		return;
 
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (document), &start, 0);
-      	gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (document), &end);
-
-	if (readonly) 
-	{
-		gtk_text_buffer_apply_tag_by_name (GTK_TEXT_BUFFER (document), 
-					NOT_EDITABLE_TAG_NAME, &start, &end);
-	}
-	else
-	{
-		gtk_text_buffer_remove_tag_by_name (GTK_TEXT_BUFFER (document), 
-					NOT_EDITABLE_TAG_NAME, &start, &end);
-	}
-
 	document->priv->readonly = readonly;
 
 	g_signal_emit (G_OBJECT (document),
@@ -502,13 +485,14 @@ gedit_document_get_short_name (const GeditDocument* doc)
 }
 
 GQuark 
-gedit_document_io_error_quark()
+gedit_document_io_error_quark (void)
 {
-  static GQuark quark;
-  if (!quark)
-    quark = g_quark_from_static_string ("gedit_io_load_error");
+	static GQuark quark;
+	
+	if (!quark)
+		quark = g_quark_from_static_string ("gedit_io_load_error");
 
-  return quark;
+	return quark;
 }
 
 static gboolean
@@ -1415,7 +1399,7 @@ gedit_document_find_again (GeditDocument* doc)
 }
 
 gchar*
-gedit_document_get_selected_text (GeditDocument *doc)
+gedit_document_get_selected_text (GeditDocument *doc, gint *start, gint *end)
 {
 	GtkTextIter iter;
 	GtkTextIter sel_bound;
@@ -1433,7 +1417,13 @@ gedit_document_get_selected_text (GeditDocument *doc)
                                     &sel_bound,
                                     gtk_text_buffer_get_mark (GTK_TEXT_BUFFER (doc),
 					                      "selection_bound"));
-	gtk_text_iter_order (&sel_bound, &iter);	
+	gtk_text_iter_order (&iter, &sel_bound);	
+
+	if (start != NULL)
+		*start = gtk_text_iter_get_offset (&iter); 
+
+	if (end != NULL)
+		*end = gtk_text_iter_get_offset (&sel_bound); 
 
 	return gtk_text_buffer_get_slice (GTK_TEXT_BUFFER (doc), &iter, &sel_bound, TRUE);
 }
@@ -1529,3 +1519,18 @@ gedit_document_replace_all (GeditDocument *doc,
 
 	return cont;
 }
+
+guint
+gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset)
+{
+	GtkTextIter iter;
+	
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
+
+	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &iter, offset);
+	
+	return gtk_text_iter_get_line (&iter);
+}
+
