@@ -29,7 +29,6 @@
  */
 
 #include <libgnome/gnome-i18n.h>
-
 #include "gedit-view.h"
 #include "gedit-debug.h"
 #include "gedit-menus.h"
@@ -64,6 +63,9 @@ static void gedit_view_cursor_moved 	(GtkTextBuffer     *buffer,
 					 GtkTextMark       *mark,
 					 gpointer           data);
 static void gedit_view_update_overwrite_mode_statusbar (GtkTextView* w, GeditView* view);
+static void gedit_view_doc_readonly_changed_handler (GeditDocument *document, 
+						     gboolean readonly, 
+						     GeditView *view);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -118,6 +120,18 @@ gedit_view_grab_focus (GtkWidget *widget)
 	
 }
 
+static void
+gedit_view_doc_readonly_changed_handler (GeditDocument *document, gboolean readonly,
+		GeditView *view)
+{
+	gedit_debug (DEBUG_VIEW, "");
+
+	g_return_if_fail (GEDIT_IS_VIEW (view));
+
+	gtk_text_view_set_editable (view->priv->text_view, !readonly);	
+}
+
+
 static void
 gedit_view_class_init (GeditViewClass *klass)
 {
@@ -142,7 +156,8 @@ gedit_view_get_lines (GtkTextView  *text_view,
 {
 	GtkTextIter iter;
 	gint count;
-	gint size;  
+	gint size;
+      	gint last_line_num;	
 
 	gedit_debug (DEBUG_VIEW, "");
 
@@ -161,13 +176,12 @@ gedit_view_get_lines (GtkTextView  *text_view,
   	while (!gtk_text_iter_is_end (&iter))
     	{
 		gint y, height;
-		gint line_num;
       
 		gtk_text_view_get_line_yrange (text_view, &iter, &y, &height);
 
 		g_array_append_val (buffer_coords, y);
-		line_num = gtk_text_iter_get_line (&iter);
-		g_array_append_val (numbers, line_num);
+		last_line_num = gtk_text_iter_get_line (&iter);
+		g_array_append_val (numbers, last_line_num);
       	
 		++count;
 
@@ -177,6 +191,23 @@ gedit_view_get_lines (GtkTextView  *text_view,
 		gtk_text_iter_forward_line (&iter);
 	}
 
+	if (gtk_text_iter_is_end (&iter))
+    	{
+		gint y, height;
+		gint line_num;
+      
+		gtk_text_view_get_line_yrange (text_view, &iter, &y, &height);
+
+		line_num = gtk_text_iter_get_line (&iter);
+
+		if (line_num != last_line_num)
+		{
+			g_array_append_val (buffer_coords, y);
+			g_array_append_val (numbers, line_num);
+			++count;
+		}
+	}
+
 	*countp = count;
 }
 
@@ -477,7 +508,14 @@ gedit_view_new (GeditDocument *doc)
 			  "toggle_overwrite",/* cursor moved */
 			  G_CALLBACK (gedit_view_update_overwrite_mode_statusbar),
 			  view);
-	
+
+	g_signal_connect (doc,
+			  "readonly_changed",
+			  G_CALLBACK (gedit_view_doc_readonly_changed_handler),
+			  view);
+
+	gtk_text_view_set_editable (view->priv->text_view, !gedit_document_is_readonly (doc));	
+
 	gedit_debug (DEBUG_VIEW, "END");
 
 	return view;
